package com.persagy.apm.energyalarmstarter.alarmengine.jms;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.apm.energyalarmstarter.alarmengine.feign.AlarmCondition;
import com.persagy.apm.energyalarmstarter.alarmengine.jms.model.DmpMessage;
import com.persagy.apm.energyalarmstarter.alarmengine.service.AlarmRecordMsgHandler;
import io.netty.channel.ChannelHandler;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * @description: 报警引擎消息处理类
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/11/30 10:31 上午
 * @version: V1.0
 */
@Slf4j
@ChannelHandler.Sharable
public class AlarmEngineMsgHandler {
    @Autowired
    private AlarmRecordMsgHandler alarmRecordMsgHandler;

    @SneakyThrows
    public String getAlarmCategory(DmpMessage dmpMessage) {
        JSONObject data = dmpMessage.getExts();
        String itemCode = data.getString("itemCode");
        return alarmRecordMsgHandler.getAlarmCategory(alarmRecordMsgHandler.getAlarmUrlParam(data), itemCode);
    }

    /**
     * @description: 创建报警记录，并发送报警记录id至边缘端
     * @param: nettyMessage
     * @return: void
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/30 3:33 下午
     * @version: V1.0
     */
    @SneakyThrows
    public void createAlarmRecordAndSendRecordId(DmpMessage dmpMessage) {
        JSONObject data = dmpMessage.getExts();
        data.put("userId", "system");
        alarmRecordMsgHandler.createAlarm(data);
    }

    /**
     * @description: 更新报警记录
     * @param: message
     * @return: void
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/30 4:13 下午
     * @version: V1.0
     */
    @SneakyThrows
    public void updateAlarmRecord(DmpMessage dmpMessage) {
        JSONObject data = dmpMessage.getExts();
        data.put("userId", "system");
        alarmRecordMsgHandler.updateAlarmRecord(data);
    }

    /**
     * @description: 报警仍在持续的处理方法
     * @param: nettyMessage
     * @return: void
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/12/17 4:44 下午
     * @version: V1.0
     */
    public void alarmContinue(DmpMessage dmpMessage) {
        log.info("报警仍在继续：{}", dmpMessage.toString());
    }

    /**
     * 同步新的报警条件
     *
     * @param msg 报警条件消息
     * @author lixing
     * @version V1.0 2021/10/26 7:51 下午
     */
    public void syncNewCondition(DmpMessage msg) {
        AlarmCondition alarmCondition = JSONObject.parseObject(msg.getStr1(), AlarmCondition.class);
        // TODO: 2021/11/16  更新redis
    }

    /**
     * 同步更新的报警条件
     *
     * @param msg 报警条件消息
     * @author lixing
     * @version V1.0 2021/10/26 7:51 下午
     */
    public void syncUpdatedCondition(DmpMessage msg) {
        AlarmCondition alarmCondition = JSONObject.parseObject(msg.getStr1(), AlarmCondition.class);
        // TODO: 2021/11/16  更新redis
    }

    /**
     * 同步删除的报警条件
     *
     * @param msg 报警条件消息
     * @author lixing
     * @version V1.0 2021/10/26 7:51 下午
     */
    public void syncDeletedCondition(DmpMessage msg) {
        AlarmCondition alarmCondition = new AlarmCondition();
        alarmCondition.setId(msg.getStr1());
        // TODO: 2021/11/16 更新redis
    }

    /**
     * 同步新的设备与报警条件关联关系
     *
     * @param msg 关联关系消息
     * @author lixing
     * @version V1.0 2021/10/26 7:51 下午
     */
    public void syncNewObjConditionRelList(DmpMessage msg) {
        JSONArray relList = JSONObject.parseArray(msg.getStr1());
        // TODO: 2021/11/16 更新redis
    }

    /**
     * 同步删除的设备与报警条件关联关系
     *
     * @param msg 关联关系消息
     * @author lixing
     * @version V1.0 2021/10/26 7:51 下午
     */
    public void syncDeletedObjConditionRelList(DmpMessage msg) {
        JSONArray relList = JSONObject.parseArray(msg.getStr1());
        // TODO: 2021/11/16 更新redis
    }

}
